#!/bin/echo usage: source
########################################################### {{{1 ###########
#  Description: Set alias names for a custom installed vim/ctags.
#     Language: Bash Shell Script
#          $Id: vim.bash 820 2007-12-08 11:05:30Z krischik $
#   Maintainer: Martin Krischik
#      $Author: krischik $
#        $Date: 2007-12-08 12:05:30 +0100 (Sa, 08 Dez 2007) $
#      Version: 3.6
#    $Revision: 820 $
#     $HeadURL: https://gnuada.svn.sourceforge.net/svnroot/gnuada/trunk/tools/vim/macros/vim.bash $
#      History: 26.07.2006 MK pretty new
#        Usage: copy to /etc/profile.d and make world executable
########################################################### }}}1 ###########


if ! type lxpm 2>/dev/null 1>/dev/null; then

    # Variablen
    UName=$(uname)

    case "${UName}" in					# {{{1
	(Linux*)					# {{{2
	    if test -x "/opt/gnat/tools/bin/vim"; then
		declare -x VIM="/opt/gnat/tools";
		declare -x VIMRUNTIME="${VIM}/share/vim/vim71";
	    else
		unset VIM 1>/dev/null 2>/dev/null;
		unset VIMRUNTIME 1>/dev/null 2>/dev/null;
	    fi;
	;;						# }}}2
	(CYGWIN*)					# {{{2
	    if test -x "/opt/gnat/tools/bin/vim"; then
		declare -x VIM="/opt/gnat/tools";
		declare -x VIMRUNTIME="${VIM}/share/vim/vim71"
	    else
		unset VIM 1>/dev/null 2>/dev/null;
		unset VIMRUNTIME 1>/dev/null 2>/dev/null;
	    fi;
	;;						# }}}2
	(SunOS)						# {{{2
	    if test -x "/opt/gnat/tools/bin/vim"; then
		declare -x VIM="/opt/gnat/tools";
		declare -x VIMRUNTIME="${VIM}/share/vim/vim71";
	    elif test -x "${HOME}/opt/gnat/tools/bin/vim"; then
		declare -x VIM="${HOME}/opt/gnat/tools";
		declare -x VIMRUNTIME="${VIM}/share/vim/vim71"
		PATH="${VIM}/bin:${PATH}"
	    else
		unset VIM 1>/dev/null 2>/dev/null;
		unset VIMRUNTIME 1>/dev/null 2>/dev/null;
	    fi
	;;						# }}}2
	(*)						# {{{2
	;;						# }}}2
    esac;						# }}}1

    # Simple Functions

    for i in ctags etags eview evim ex gview gvim gvimdiff rgview rgvim rview rvim view vim vimdiff vimtutor xxd; do # {{{1

	case "${UName}" in				# {{{2
	    (MINGW*)					# {{{3
		if test -n "${VIM}"; then
		    declare -x -f ${i};

		    eval "function ${i} ()
			{
			${VIM}/vim71/gvim.exe \"\${@}\"
			return;
			}"
		else
		    unset -f ${i} 1>/dev/null 2>/dev/null;
		fi;
	    ;; # }}}3
	    (Linux|CYGWIN*)				# {{{3
		if test -n "${VIM}"; then
		    declare -x -f ${i};

		    eval "function ${i} ()
			    {
			    LD_LIBRARY_PATH=\"\${LD_LIBRARY_PATH}:${VIM}/lib\"  \
			    \"${VIM}/bin/${i}\" \"\${@}\"			;
			    return;
			    }"
		else
		    unset -f ${i} 1>/dev/null 2>/dev/null;
		fi;
	    ;;						# }}}3
	    (*)						# {{{3
	    ;;						# }}}3
	esac;						# }}}2
    done;						# }}}1

    # Server Functions

    for i in lxpm med epm; do				# {{{1
	declare -x -f ${i}

	case "${UName}" in				# {{{2
	    (MINGW*)					# {{{3
		if test -n "${VIM}"; then
		    eval "function ${i} ()
			{
			if test -z "\${1}"; then
			    ${VIM}/vim71/gvim.exe --servername ${i} 1>/dev/null 2>/dev/null &
			else
			    ${VIM}/vim71/gvim.exe --servername ${i} --remote-silent \"\${@}\" 1>/dev/null 2>/dev/null &
			fi;
			return;
			}"
		else
		    eval "function ${i} ()
			{
			if test -z "\${1}"; then
			    gvim.exe --servername ${i} 1>/dev/null 2>/dev/null &
			else
			    gvim.exe --servername ${i} --remote-silent \"\${@}\" 1>/dev/null 2>/dev/null &
			fi;
			return;
			}"
		fi;
	    ;;						# }}}3
	    (Linux|CYGWIN*|SunOS)			# {{{3
		if test -n "${VIM}"; then
		    eval "function ${i} ()
			{
			if test -z \"\${1}\"; then
			    LD_LIBRARY_PATH=\"\${LD_LIBRARY_PATH}:${VIM}/lib\"			\
			    \"${VIM}/bin/gvim\" --servername \"${i} ${HOSTNAME}\" \"\${@}\"	\
			    >/dev/null 2>/dev/null &
			else
			    LD_LIBRARY_PATH=\"\${LD_LIBRARY_PATH}:${VIM}/lib\"				    \
			    \"${VIM}/bin/gvim\" --servername \"${i} ${HOSTNAME}\" --remote-silent \"\${@}\" \
			    >/dev/null 2>/dev/null &
			fi
			return;
			}"
		else
		    eval "function ${i} ()
			{
			if test -z \"\${1}\"; then
			    gvim --servername \"${i} ${HOSTNAME}\" >/dev/null 2>/dev/null &
			else
			    gvim --servername \"${i} ${HOSTNAME}\" --remote-silent \"\${@}\" >/dev/null 2>/dev/null &
			fi
			return;
			}"
		fi;
	    ;;						# }}}3
	    (*)						# {{{3
	    ;;						# }}}3
	esac;						# }}}2
    done;						# }}}1

    # Some applications read the EDITOR variable to determine your favourite text
    # editor. So uncomment the line below and enter the editor of your choice :-)
    if test -n "${VIM}"; then
	declare -x EDITOR="${VIM}/bin/gvim -f";
	declare -x VISUAL="${VIM}/bin/gvim -f";
    else
	declare -x EDITOR="$(which gvim) -f";
	declare -x VISUAL="$(which gvim) -f";
    fi;
    # Unset local Variablen

    unset UName

    printf "\e[42m%-30.30s : \e[43m %-40.40s \e[m\n" "$(basename ${BASH_SOURCE:-${0}})" "VIM 7.0 symbols set."

fi;

########################################################### {{{1 ###########
#   Copyright (C) 2006	Martin Krischik
#
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License
#   as published by the Free Software Foundation; either version 2
#   of the License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
########################################################### }}}1 ###########
# vim: textwidth=0 nowrap tabstop=8 shiftwidth=4 softtabstop=4 noexpandtab
# vim: filetype=sh encoding=utf-8 fileformat=unix foldmethod=marker
